aboutsummaryrefslogtreecommitdiff
path: root/ef-light-theme.el
diff options
context:
space:
mode:
authorProtesilaos Stavrou <info@protesilaos.com>2022-09-07 06:19:10 +0300
committerProtesilaos Stavrou <info@protesilaos.com>2022-09-07 06:19:10 +0300
commitc11d7b767134be9a7b91453e2792fe009c7529b7 (patch)
tree85207f0378436a6cbec1c52087acdca500418e88 /ef-light-theme.el
parent0416ea8554a78e8ae352fb314a336672b048d41c (diff)
Make theme one-line descriptions more descriptive
Diffstat (limited to 'ef-light-theme.el')
-rw-r--r--ef-light-theme.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/ef-light-theme.el b/ef-light-theme.el
index ca12983..b13df6d 100644
--- a/ef-light-theme.el
+++ b/ef-light-theme.el
@@ -1,4 +1,4 @@
;;; ef-light-theme.el --- Legible light theme with blue and magenta colors -*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
@@ -37,7 +37,7 @@
(eval-and-compile
(require 'ef-themes)
- (deftheme ef-light "Legible light theme with blue and magenta colors.")
+ (deftheme ef-light "Legible light theme with blue, magenta, cyan, purple colors.")
(defconst ef-light-palette
'(;; Basic tones
@@ -1,4 +1,4 @@
-;;; ef-light-theme.el --- Legible light theme with blue and magenta colors -*- lexical-binding:t -*-
+;;; ef-light-theme.el --- Legible light theme with blue, magenta, cyan, purple colors -*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.